# Release 0.8.9

!!!tip inline end "Need Help?"
    The SuperCowPowers team is happy to give any assistance needed when setting up AWS and SageWorks. So please contact us at [sageworks@supercowpowers.com](mailto:sageworks@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 

The SageWorks framework continues to 'flex' to support different real world use cases when operating a set of production machine learning pipelines.

### General
The AWSAccountClamp had too many responsibilities so that class has been split up into two classes and a set of utilities:

- AWSAccountClamp
- AWSSession
- utils/execution_environment.py

### API Changes
- **Column Names**

	```
	data_source.column_names() --> data_source.columns
	feature_set.column_names() --> feature_set.columns
	```

- **Display/Training Views**

	```
	data_source.get_display_view() --> data_source.view("display")
	feature_set.get_display_view() --> feature_set.view("display")
	feature_set.get_training_view() --> feature_set.view("training")
	```

- **AWSAccountClamp**

	```
	AWSAccountClamp().boto_session() --> AWSAccountClamp().boto3_session
	```

- **All Classes**

    If the class previously had a `boto_session` attribute that has been renamed to `boto3_session`
 
### Glue Job Fixes
For `sageworks==0.8.8` you needed to be careful about when/where you set your config/ENV vars. With `0.8.9` you can now use the typical setup like this:

	```
	from sageworks.utils.config_manager import ConfigManager
	
	# Set the SageWorks Config
	cm = ConfigManager()
	cm.set_config("SAGEWORKS_BUCKET", args_dict["sageworks-bucket"])
	cm.set_config("REDIS_HOST", args_dict["redis-host"])
	```

### Robust ModelNotReadyException Handling
AWS will 'deep freeze' Serverless Endpoints and if that endpoint hasn't been used for a while it can sometimes take a long time to come up and be ready for inference. SageWorks now properly manages this AWS error condition, it will report the issue, wait 60 seconds, and try again 5 times before raising the exception.

```
(endpoint_core.py:502) ERROR Endpoint model not ready
(endpoint_core.py:503) ERROR Waiting and Retrying...
...
After a while, inference will run successfully :)
```

### Questions?
<img align="right" src="../../images/scp.png" width="180">

The SuperCowPowers team is happy to anser any questions you may have about AWS and SageWorks. Please contact us at [sageworks@supercowpowers.com](mailto:sageworks@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 


